pub struct Static;Trait Implementations
Sourceimpl<D> Decode<Static, D> for Staticwhere
D: ResourceDialect,
impl<D> Decode<Static, D> for Staticwhere
D: ResourceDialect,
Sourceimpl Ord for Static
impl Ord for Static
Sourceimpl PartialOrd for Static
impl PartialOrd for Static
Sourceimpl TypeMarker for Static
impl TypeMarker for Static
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for Static
impl ValueTypeMarker for Static
Sourcetype Borrowed<'a> = &'a Static
type Borrowed<'a> = &'a Static
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<Static as TypeMarker>::Owned,
) -> <Static as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<Static as TypeMarker>::Owned, ) -> <Static as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Copy for Static
impl Eq for Static
impl Persistable for Static
impl StructuralPartialEq for Static