#[repr(C)]pub struct TxPartialCsumMetadata {
pub start: u16,
pub offset: u16,
}Expand description
Partial checksum metadata.
Fields
start: u16The offset in bytes from the start of the frame to where the device must begin computing the checksum.
offset: u16The offset in bytes from the start of the checksummed portion of the buffer to where the device must place the checksum result. The checksum field itself is included in the checksum.